# -*- coding: utf-8 -*-
from Components.config import config, configfile, ConfigText, ConfigSubsection
from Plugins.Plugin import PluginDescriptor
from enigma import getExitCode
from pywebostv.connection import *
from pywebostv.controls import *
from pywebostv.discovery import *
import requests

class LGTV(object):
	def __init__(self):
		print("LGTVPowerOff: Init")
		config.misc.standbyCounter.addNotifier(self.EnterStandby, initial_call = False)
		config.plugins.LGTVPowerOff = ConfigSubsection()
		config.plugins.LGTVPowerOff.key = ConfigText()
		config.plugins.LGTVPowerOff.ip = ConfigText()

	def EnterStandby(self, element):
		print("LGTVPowerOff: Enter Standby")
		from Screens.Standby import inStandby
		inStandby.onClose.append(self.LeaveStandby)
		if not config.plugins.LGTVPowerOff.ip.value:
			print("LGTVPowerOff: No LGTV configured, scanning network - please wait...")
			client = WebOSClient.discover()
			if len(client):
				for i in xrange(0, len(client)):
					print("LGTVPowerOff: found LGTV #%s [%s]" % (1 + i, client[i].host))
				config.plugins.LGTVPowerOff.ip.value = client[0].host
				config.plugins.LGTVPowerOff.ip.save()
				configfile.save()
			else:
				print("LGTVPowerOff: no LGTV found, check network!")
		self.powerOff()

	def LeaveStandby(self):
		print("LGTVPowerOff: Leave Standby")

	def powerOff(self):
		print("LGTVPowerOff: PowerOff")
		try:
			requests.get("http://%s:3000" % config.plugins.LGTVPowerOff.ip.value, timeout = 1)
			store = {"client_key": config.plugins.LGTVPowerOff.key.value}
			client = WebOSClient(config.plugins.LGTVPowerOff.ip.value)
			try:
				client.connect()
				for status in client.register(store):
					if status == WebOSClient.PROMPTED:
						print("LGTVPowerOff: Please accept connection on TV")
					elif status == WebOSClient.REGISTERED:
						print("LGTVPowerOff: Registration with key \"%s\" successful" % store["client_key"])
						if store["client_key"] != config.plugins.LGTVPowerOff.key.value:
							print("LGTVPowerOff: Key changed from \"%s\" to \"%s\"" % (config.plugins.LGTVPowerOff.key.value, store["client_key"]))
							config.plugins.LGTVPowerOff.key.value = store["client_key"]
							config.plugins.LGTVPowerOff.key.save()
							configfile.save()
						system = SystemControl(client)
						system.power_off()
			except:
				print("LGTVPowerOff: Registration with TV failed")
		except requests.ConnectionError:
			print("LGTVPowerOff: TV %s offline or \"LG Connected Apps\" disabled" % config.plugins.LGTVPowerOff.ip.value)

lgtv = LGTV()

def autostart(reason, **kwargs):
	session = kwargs.get('session', None)
	if session is not None:
		print("LGTVPowerOff: AutoStart")
		lgtv.session = session
	elif getExitCode() == 1:
		lgtv.powerOff()

def Plugins(**kwargs):
	return PluginDescriptor(name = "LGTVPowerOff", where = [PluginDescriptor.WHERE_SESSIONSTART, PluginDescriptor.WHERE_AUTOSTART] , fnc = autostart)

